/***************************************************************************
 *   Copyright (C) 2004 by Stephen Anthony                                 *
 *   stephena@users.sourceforge.net                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef GAMELISTDOC_H
#define GAMELISTDOC_H

#include <qobject.h>
#include <qstring.h>

#include <kconfig.h>
#include <kprocess.h>

#include "gamelist.h"
#include "game.h"


/**	This class takes care of generating / storing all game roms in the system.
	All properties of all possible games (from the stella.pro file) are stored
	in a game list, which the GameListView uses to show onscreen.
*/
class GameListDoc : public QObject
{
  Q_OBJECT

	public:
		/** Constructor for the application */
		GameListDoc( QWidget* parent, const char* name = 0 );
		/** Destructor for the application */
		~GameListDoc( void );

		/** load the gamelist with Stella properties data, which could come from disk or cache */
		void load( void );

		/** force a reload (from disk) of the Stella properties file */
		void reload( void );

		/** returns the game list */
		GameList* gameList( void );

		/** returns a string consisting of the current game info */
		QString gameStatistics( void );

	private:
		/** load the Stella game information from a stella properties file */
		void loadGameProperties( const QString& filename );

		/** determine which games are available in the ROM directory */
		void updateGameList( const QString& romDir );

		/** cache the game list */
		void createCache( void );

		/** load the game list from the kstella cache */
		void loadFromCache( void );

		/** load the game list by actually rescanning the rom directory */
		void loadFromDisk( void );

	signals:
		/** Emitted when the gamelist has changed */
		void gameListChanged( void );

	private:
		/** the list of all the Atari2600 games */
		GameList* list;

		/** the configuration object of the application */
		KConfig* config;

		/** total number of games found in the properties file */
		int numTotalGames;

		/** actual number of games the user has */
		int numActualGames;
};

#endif
