/***************************************************************************
 *   Copyright (C) 2004 by Stephen Anthony                                 *
 *   stephena@users.sourceforge.net                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef GAMELISTVIEW_H
#define GAMELISTVIEW_H

#include <qtimer.h>
#include <qlistview.h>

#include <kconfig.h>

#include "game.h"
#include "gamelist.h"


/** This class contains the list of games (in a QListView) with options to
	view certain headings (manufacturer, note, rarity).
*/
class GameListView : public QListView
{
  Q_OBJECT

	public:
		GameListView( QWidget* parent = 0, const char* name = 0 );
		~GameListView( void );

		/** let this class know about the game list */
		void setGameList( GameList* list );

		/** toggle showing the rarity column */
		void showRarity( bool show );

		/** toggle showing the manufacturer column */
		void showManufacturer( bool show );

		/** toggle showing the note column */
		void showNote( bool show );

		/** returns the currently selected game */
		Game* currentGame( void );

	public slots:
		/** show the (updated) game list */
		void update( void );

	private slots:
		/** update the view based upon the current item in the game list */
		void slotSelectionChanged( QListViewItem* item );

		/** called when the timer is finished */
		void slotSelectionTimerFinished( void );

		/** indicates that a game is to be emulated */
		void slotEmulate( QListViewItem* item );

	signals:
		/** Emitted when the tab should be changed.  If direction is 1, then the next
			rightmost tab is selected, else the next leftmost tab is selected */
		void changeTab( int direction );

		/** Emitted when a selection should be changed to the given game
			in the parent class */
		void changeSelection( Game* g );

		/** Emitted when the currently selected game should be emulated */
		void startEmulation( void );

	private:
		/** Reimplemented to take care of changing tabs */
		void keyPressEvent( QKeyEvent* e );

		/** resize the given column to the given size */
		void resizeColumn( int column, int size );

	private:
		/** the configuration object of the application */
		KConfig* config;

		/** the game list which contains all the games in the system */
		GameList* gameList;

		/** used to delay processing a selection for a while */
		QTimer* selectionTimer;

		/** used to save lookup of current list item */
		QListViewItem* currentItem;
};

#endif
