/***************************************************************************
 *   Copyright (C) 2004 by Stephen Anthony                                 *
 *   stephena@users.sourceforge.net                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <qwidget.h>
#include <kconfig.h>

#include "settingsdlg.h"


/** This class defines either the system-wide default game settings or
	the per-game settings.

	*@author Stephen Anthony
*/
class Settings : public SettingsDlg
{
  Q_OBJECT
	public:
		Settings( QWidget* parent, const char* name, const QString& title, const QString& group );
		~Settings( void );

		/** reads the settings of the given group */
		void readConfig( const QString& group );

		/** saves the settings of the given group */
		void writeConfig( const QString& group );

	protected slots:
		/** called when the default button is pressed */
		void slotDefaultsClicked( void );

		/** called when the OK button is pressed */
		void slotOKClicked( void );

		/** called to toggle between using default system volume */
		void slotVolumeDisableToggled( bool toggle );

		/** called to toggle between using sound */
		void slotSoundDisableToggled( bool toggle );

		/** called to toggle OpenGL settings */
		void slotVideoDriverActivated( int index );

	private:
		/** the configuration object of the application */
		KConfig* config;

		/** the current group being modified */
		QString _group;
};

#endif
