/***************************************************************************
 *   Copyright (C) 2004 by Stephen Anthony                                 *
 *   stephena@users.sourceforge.net                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

using namespace std;

#include <kfiledialog.h>
#include <kapplication.h>

#include <qlineedit.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qdir.h>

#include "setup.h"


Setup::Setup( QWidget *parent, const char *name )
	 : SetupDlg( parent, name, TRUE )
{
	setCaption( "KStella - Emulator Defaults" );
	readConfig();
}


Setup::~Setup( void )
{
}


void Setup::slotDefaultsClicked( void )
{
	binaryEdit->setText( "stella" );

	// try to automatically determine the stella documentation directory
	QDir d( "/usr/share/doc/", "stella*", QDir::Name|QDir::IgnoreCase|QDir::Reversed, QDir::Dirs );
	if( d.count() > 0 && d[0] != NULL )
	{
		QString docdir = "/usr/share/doc/" + d[0];
		docDirEdit->setText( docdir );
	}
	
	romDirEdit->setText( "!!! CHANGE ME !!!" );
	snapShotDirEdit->setText( "/usr/share/kstella-snapshots" );
	labelDirEdit->setText( "/usr/share/kstella-labels" );
	manualDirEdit->setText( "/usr/share/kstella-manuals" );

	snapShotMultipleButton->setChecked( FALSE );
	snapShotNameComboBox->setCurrentItem( 1 );		// md5sum
	snapShotLocationComboBox->setCurrentItem( 1 );	// snapshot dir
}


void Setup::slotOKClicked( void )
{
	// write the configuration immediately, not upon program exit
	writeConfig();
	accept();
}


void Setup::slotBinaryClicked( void )
{
	// open the directory dialog
	QString string = KFileDialog::getOpenFileName();

	if( !string.isNull() )
		binaryEdit->setText( string );
}


void Setup::slotDocDirClicked( void )
{
	// open the directory dialog to the default doc directory
	QString string = KFileDialog::getExistingDirectory( "/usr/share/doc", 0, "Stella Documentation" );

	if( !string.isNull() )
		docDirEdit->setText( string );
}


void Setup::slotRomDirClicked( void )
{
	// open the directory dialog
	QString string = KFileDialog::getExistingDirectory( QString::null, 0, "Rom Directory" );

	if( !string.isNull() )
		romDirEdit->setText( string );
}


void Setup::slotSnapShotDirClicked( void )
{
	// open the directory dialog
	QString string = KFileDialog::getExistingDirectory( QString::null, 0, "Snapshot Directory" );

	if( !string.isNull() )
		snapShotDirEdit->setText( string );
}


void Setup::slotLabelDirClicked( void )
{
	// open the directory dialog
	QString string = KFileDialog::getExistingDirectory( QString::null, 0, "Label Directory" );

	if( !string.isNull() )
		labelDirEdit->setText( string );
}


void Setup::slotManualDirClicked( void )
{
	// open the directory dialog
	QString string = KFileDialog::getExistingDirectory( QString::null, 0, "Manual Directory" );

	if( !string.isNull() )
		manualDirEdit->setText( string );
}


void Setup::readConfig( void )
{
	// temporary variable
	QString string;
	bool b;
	int i;

	config = kapp->config();
	config->setGroup( "Emulator Defaults" );

	string = config->readEntry( "Binary" );
	binaryEdit->setText( string );
	string = config->readEntry( "DocDir" );
	docDirEdit->setText( string );

	string = config->readEntry( "RomDir" );
	romDirEdit->setText( string );
	string = config->readEntry( "SnapshotDir" );
	snapShotDirEdit->setText( string );
	string = config->readEntry( "LabelDir" );
	labelDirEdit->setText( string );
	string = config->readEntry( "ManualDir" );
	manualDirEdit->setText( string );

	b = config->readBoolEntry( "SnapshotMultiple" );
	snapShotMultipleButton->setChecked( b );
	i = config->readNumEntry( "SnapshotName" );
	snapShotNameComboBox->setCurrentItem( i );
	i = config->readNumEntry( "SnapshotLocation" );
	snapShotLocationComboBox->setCurrentItem( i );
}


void Setup::writeConfig( void )
{
	QString s, args;

	config->setGroup( "Emulator Defaults" );

	config->writeEntry( "Binary", binaryEdit->text() );
	config->writeEntry( "DocDir", docDirEdit->text() );

	config->writeEntry( "RomDir", romDirEdit->text() );
	config->writeEntry( "SnapshotDir", snapShotDirEdit->text() );
	config->writeEntry( "LabelDir", labelDirEdit->text() );
	config->writeEntry( "ManualDir", manualDirEdit->text() );

	config->writeEntry( "SnapshotMultiple", snapShotMultipleButton->isChecked() );
	config->writeEntry( "SnapshotName", snapShotNameComboBox->currentItem() );
	config->writeEntry( "SnapshotLocation", snapShotLocationComboBox->currentItem() );

	// "sssingle" command line argument
	args += " -sssingle ";
	args += snapShotMultipleButton->isChecked() ? "0" : "1";

	// "ssname" command line argument
	s = snapShotNameComboBox->currentText();
	if( s == "Cartridge Name" )
		args += " -ssname romname";
	else if( s == "Cartridge MD5" )
		args += " -ssname md5sum";

	// "ssdir" command line argument
	s = snapShotLocationComboBox->currentText();
	if( s == "Snapshot Dir" )
	{
		s = snapShotDirEdit->text();
		if( s.length() > 0 )
			args += " -ssdir \"" + s + "\"";
	}

	// write all the game command line arguments into one big command
	config->writeEntry( "EmulatorArgs", args );

	// make sure to actually write this config NOW not upon program exit
	config->sync();
}
